@@ -3,7 +3,7 @@ BEGIN {
   $Dancer::Template::Mason::AUTHORITY = 'cpan:yanick';
 }
 BEGIN {
-  $Dancer::Template::Mason::VERSION = '0.003002';
+  $Dancer::Template::Mason::VERSION = '0.003003';
 }
 # ABSTRACT: Mason wrapper for Dancer
 
@@ -20,11 +20,16 @@ my $root_dir;
 
 sub init { 
     my $self = shift;
-    my $config = $self->config || {};
+    my %config = %{$self->config || {}};
 
-    $root_dir = $config->{comp_root} ||= setting('views') || $FindBin::Bin . '/views';
+    $root_dir = $config{comp_root} ||= setting('views') || $FindBin::Bin . '/views';
 
-    $_engine = HTML::Mason::Interp->new( %$config );
+    # The "extension" parameter is used by Dancer to override the
+    # default template extension, but it can't be passed to
+    # HTML::Mason::Interp, which checks for unknown parameters.
+    delete $config{'extension'};
+
+    $_engine = HTML::Mason::Interp->new( %config );
 }
 
 sub default_tmpl_ext { "mason" };
@@ -51,7 +56,7 @@ Dancer::Template::Mason - Mason wrapper for Dancer
 
 =head1 VERSION
 
-version 0.003002
+version 0.003003
 
 =head1 SYNOPSIS
 
